
#ifndef __ephy_marshal_MARSHAL_H__
#define __ephy_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (./ephy-marshal.list:1) */
#define ephy_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:STRING (./ephy-marshal.list:2) */
#define ephy_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:OBJECT (./ephy-marshal.list:3) */
#define ephy_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,POINTER (./ephy-marshal.list:4) */
extern void ephy_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:OBJECT,OBJECT,INT (./ephy-marshal.list:5) */
extern void ephy_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:OBJECT,STRING,INT (./ephy-marshal.list:6) */
extern void ephy_marshal_VOID__OBJECT_STRING_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:OBJECT,INT (./ephy-marshal.list:7) */
extern void ephy_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:OBJECT,INT,INT (./ephy-marshal.list:8) */
extern void ephy_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:POINTER,INT (./ephy-marshal.list:9) */
extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:STRING,INT,INT (./ephy-marshal.list:10) */
extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* VOID:STRING,INT (./ephy-marshal.list:11) */
extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:STRING,STRING (./ephy-marshal.list:12) */
extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* INT:STRING (./ephy-marshal.list:13) */
extern void ephy_marshal_INT__STRING (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:INT,INT (./ephy-marshal.list:14) */
extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
                                        const GValue *param_values,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);

/* VOID:INT,INT,INT (./ephy-marshal.list:15) */
extern void ephy_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* INT:OBJECT (./ephy-marshal.list:16) */
extern void ephy_marshal_INT__OBJECT (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);

/* VOID:POINTER,POINTER (./ephy-marshal.list:17) */
extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

/* VOID:FLOAT (./ephy-marshal.list:18) */
#define ephy_marshal_VOID__FLOAT	g_cclosure_marshal_VOID__FLOAT

G_END_DECLS

#endif /* __ephy_marshal_MARSHAL_H__ */

